==> react-native-hotqa-sdk-0.2.2.tgz: package/src/pages/home/home.js <==
import React, {useEffect, useState} from 'react';
import {
  TouchableOpacity,
  View,
  Text,
  SafeAreaView,
  Image,
  ActivityIndicator,
  Alert,
  ScrollView,
} from 'react-native';
import moment from 'moment';
import {useDispatch, useSelector} from 'react-redux';
import SharePreference from '../../common/SharePreference';
import * as actions from '../../redux/actions';
import {createSelector} from 'reselect';
import AntDesign from 'react-native-vector-icons/AntDesign';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import MaterialIcons from 'react-native-vector-icons/MaterialIcons';
import RNExitApp from 'react-native-exit-app';
import HTMLView from 'react-native-htmlview';
import logo from '../../assets/images/logo.png';
import DownloadAudio from '../start/view/download-sound';
import {styles} from './styles';
import {hideCotrolAndroid} from '../../common/helper';

AntDesign.loadFont();
FontAwesome.loadFont();
MaterialIcons.loadFont();

const getData = createSelector(
  (state) => state.reducersAccepted,
  (reducersAccepted) => reducersAccepted,
);

let downloadAudio;

export default (props) => {
  const {navigation, route} = props;
  const dispatch = useDispatch();
  const {data, error} = useSelector(getData);
  const [loading, setLoading] = useState(false);
  const {
    isFinish,
    isResult,
    token,
    student_id,
    domain,
    student_name,
  } = route.params;

  useEffect(() => {
    hideCotrolAndroid();
    if (route.params?.linkUrl) {
      getInfoFromUrl(route.params.linkUrl);
    } else {
      // getInfoFromUrl(fixLinkTest);
    }
  }, []);

  const getInfoFromUrl = (linkQA) => {
    if (linkQA && linkQA.includes('code=')) {
      const arrSplit = linkQA.split('code=');
      if (arrSplit.length > 0) {
        const code = arrSplit[1];
        let domainHotqa = 'test.ekidpro.com';
        const arrSplit2 = linkQA.split('/');
        if (arrSplit2.length > 3) {
          domainHotqa = arrSplit2[2];
        }
        if (arrSplit2.length > 5) {
          if (arrSplit2[5] === 'free') {
            SharePreference.isTest = false;
          } else {
            SharePreference.isTest = true;
          }
        } else {
          SharePreference.isTest = false;
        }
        const auth = {
          device_id: '',
          domain: domainHotqa,
          code: code,
        };
        let param;
        if (isResult) {
          param = {
            auth: domain,
            test_id: arrSplit2[6],
            student_id: student_id,
            token: token,
          };
        } else {
          param = {
            auth: auth,
            test_id: arrSplit2[6],
          };
        }
        dispatch({
          type: actions.REQUEST_IS_RESULT,
          payload: {isResult},
        });
        if (isResult) {
          dispatch({type: actions.REQUEST_SECTION_INFO, payload: param});
        } else {
          dispatch({type: actions.REQUEST_AUTHENCATION, payload: param});
        }
      }
    }
  };

  const download = () => {
    setLoading(true);
    downloadAudio = new DownloadAudio({data: data, start: () => startTest()});
    if (downloadAudio) {
      downloadAudio.getArrLink();
    }
  };

  const startTest = () => {
    setLoading(false);
    dispatch({
      type: actions.REQUEST_IS_FINISH,
      payload: {isFinish},
    });
    SharePreference.startTest = moment().unix();
    navigation.replace('Start');
  };

  const backExit = () => {
    hideCotrolAndroid();
    if (downloadAudio) {
      downloadAudio.stopDownload();
    }
    dispatch({type: actions.REQUEST_CLEAR_DATA});
    route.params?.nav ? route.params.nav.goBack() : RNExitApp.exitApp();
  };

  if (data == null && !error) {
    return (
      <View style={styles.container}>
        <ActivityIndicator size="large" color="#7d9db5" />
      </View>
    );
  }

  if (error) {
    return (
      <>
        {Alert.alert('', error, [
          {
            text: 'Thoát',
            onPress: () => backExit(),
          },
        ])}
      </>
    );
  }

  return (
    <SafeAreaView style={styles.safe}>
      <ScrollView>
        <View style={styles.flexView}>
          <TouchableOpacity
            style={styles.btnBack}
            onPress={() => {
              dispatch({type: actions.REQUEST_CLEAR_DATA});
              if (route) {
                route.params?.nav.goBack();
              }
            }}>
            <MaterialIcons name="keyboard-backspace" style={styles.iconBack} />
          </TouchableOpacity>
          <Image style={styles.logo} source={logo} resizeMode="contain" />
        </View>
        <View style={styles.content}>
          <View style={styles.viewShadow}>
            <View style={styles.viewRadius}>
              <Text
                style={{fontSize: 70, fontWeight: 'bold', color: '#0abb87'}}>
                E
              </Text>
            </View>
          </View>
          <View style={styles.body}>
            <Text style={styles.title}>{data.title}</Text>
            <HTMLView value={data.outline} style={{marginHorizontal: 40}} />
          </View>

          <View style={styles.viewUser}>
            <Text style={styles.hintName}>Học sinh: </Text>
            <Text style={styles.name}>{student_name}</Text>
          </View>
          <View style={styles.quizView}>
            <View
              style={{
                flexDirection: 'row',
                alignItems: 'center',
              }}>
              <View style={{width: 100}}>
                <Text style={styles.subHeader}>{data.total_questions}</Text>
                <Text style={styles.subHeader}>câu hỏi</Text>
              </View>
            </View>
            <View style={styles.viewTime}>
              <Text style={styles.time}>{data.time_limit}p</Text>
              <Text style={styles.time}>thời gian làm bài</Text>
            </View>
          </View>
          <TouchableOpacity
            style={styles.button}
            disabled={loading}
            onPress={download}>
            {loading ? (
              <ActivityIndicator size="small" color="#FFF" />
            ) : (
              <Text style={styles.textButton}>Bắt đầu</Text>
            )}
          </TouchableOpacity>
        </View>
      </ScrollView>
    </SafeAreaView>
  );
};

==> react-native-hotqa-sdk-0.2.4.tgz: package/src/pages/home/home.js <==
import React, {useEffect, useState} from 'react';
import {
  TouchableOpacity,
  View,
  Text,
  SafeAreaView,
  Image,
  ActivityIndicator,
  Alert,
} from 'react-native';
import moment from 'moment';
import {useDispatch, useSelector} from 'react-redux';
import SharePreference from '../../common/SharePreference';
import * as actions from '../../redux/actions';
import {createSelector} from 'reselect';
import AntDesign from 'react-native-vector-icons/AntDesign';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import MaterialIcons from 'react-native-vector-icons/MaterialIcons';
import RNExitApp from 'react-native-exit-app';
// import logo from '../../assets/images/logo.png';
import ic_tutorial from '../../assets/images/ic_tutorial.png';
import ic_clock_orange from '../../assets/images/ic_clock_orange.png';
import ic_question from '../../assets/images/ic_question.png';
import DownloadAudio from '../start/view/download-sound';
import {styles} from './styles';
import {hideCotrolAndroid} from '../../common/helper';

AntDesign.loadFont();
FontAwesome.loadFont();
MaterialIcons.loadFont();

const getData = createSelector(
  (state) => state.reducersAccepted,
  (reducersAccepted) => reducersAccepted,
);

let downloadAudio;

export default (props) => {
  const {navigation, route} = props;
  const dispatch = useDispatch();
  const {data, error} = useSelector(getData);
  const [loading, setLoading] = useState(false);
  const {isFinish, isResult, token, student_id, domain} = route.params;

  useEffect(() => {
    hideCotrolAndroid();
    if (route.params?.linkUrl) {
      getInfoFromUrl(route.params.linkUrl);
    } else {
      // getInfoFromUrl(fixLinkTest);
    }
  }, []);

  const getInfoFromUrl = (linkQA) => {
    if (linkQA && linkQA.includes('code=')) {
      const arrSplit = linkQA.split('code=');
      if (arrSplit.length > 0) {
        const code = arrSplit[1];
        let domainHotqa = 'test.ekidpro.com';
        const arrSplit2 = linkQA.split('/');
        if (arrSplit2.length > 3) {
          domainHotqa = arrSplit2[2];
        }
        if (arrSplit2.length > 5) {
          if (arrSplit2[5] === 'free') {
            SharePreference.isTest = false;
          } else {
            SharePreference.isTest = true;
          }
        } else {
          SharePreference.isTest = false;
        }
        const auth = {
          device_id: '',
          domain: domainHotqa,
          code: code,
        };
        let param;
        if (isResult) {
          param = {
            auth: domain,
            test_id: arrSplit2[6],
            student_id: student_id,
            token: token,
          };
        } else {
          param = {
            auth: auth,
            test_id: arrSplit2[6],
          };
        }
        dispatch({
          type: actions.REQUEST_IS_RESULT,
          payload: {isResult},
        });
        if (isResult) {
          dispatch({type: actions.REQUEST_SECTION_INFO, payload: param});
        } else {
          dispatch({type: actions.REQUEST_AUTHENCATION, payload: param});
        }
      }
    }
  };

  const download = () => {
    setLoading(true);
    downloadAudio = new DownloadAudio({data: data, start: () => startTest()});
    if (downloadAudio) {
      downloadAudio.getArrLink();
    }
  };

  const startTest = () => {
    setLoading(false);
    dispatch({
      type: actions.REQUEST_IS_FINISH,
      payload: {isFinish},
    });
    SharePreference.startTest = moment().unix();
    navigation.replace('Start');
  };

  const backExit = () => {
    hideCotrolAndroid();
    if (downloadAudio) {
      downloadAudio.stopDownload();
    }
    dispatch({type: actions.REQUEST_CLEAR_DATA});
    route.params?.nav ? route.params.nav.goBack() : RNExitApp.exitApp();
  };

  if (data == null && !error) {
    return (
      <View style={styles.container}>
        <ActivityIndicator size="large" color="#7d9db5" />
      </View>
    );
  }

  if (error) {
    return (
      <>
        {Alert.alert('', error, [
          {
            text: 'Thoát',
            onPress: () => backExit(),
          },
        ])}
      </>
    );
  }

  return (
    <SafeAreaView style={styles.safe}>
      <View style={styles.content}>
        <Text style={styles.title}>{data.title}</Text>
        <View style={styles.quizView}>
          <View style={styles.viewInfo}>
            <Image
              source={ic_clock_orange}
              resizeMode="contain"
              style={styles.iconClock}
            />
            <Text style={styles.time}>Thời gian: {data.time_limit} phút</Text>
          </View>
          <View style={styles.viewInfo}>
            <Image
              source={ic_question}
              resizeMode="contain"
              style={styles.iconQuestion}
            />
            <Text style={styles.time}>Câu hỏi: {data.total_questions}</Text>
          </View>
        </View>

        <Text style={[styles.textSize30, {color: '#4C51D9'}]}>
          Bạn đã sẵn sàng chưa?
        </Text>

        <TouchableOpacity
          style={styles.button}
          disabled={loading}
          onPress={download}>
          {loading ? (
            <ActivityIndicator size="small" color="#FFF" />
          ) : (
            <Text style={styles.textSize30}>
              {!isFinish ? 'Sẵn sàng' : 'Xem kết quả'}
            </Text>
          )}
        </TouchableOpacity>
      </View>
      <View style={styles.flexView}>
        <TouchableOpacity
          style={styles.btnBack}
          onPress={() => {
            dispatch({type: actions.REQUEST_CLEAR_DATA});
            if (route) {
              route.params?.nav.goBack();
            }
          }}>
          <MaterialIcons name="keyboard-backspace" style={styles.iconBack} />
        </TouchableOpacity>
        {/* <TouchableOpacity style={styles.btnTutorial}>
          <Image
            style={styles.iconTutorial}
            source={ic_tutorial}
            resizeMode="contain"
          />
        </TouchableOpacity> */}
      </View>
    </SafeAreaView>
  );
};
